@@ -1,7 +1,9 @@
+## no critic: InputOutput::ProhibitOneArgSelect
+
 package File::Write::Rotate;
 
-our $DATE = '2016-06-06'; # DATE
-our $VERSION = '0.30'; # VERSION
+our $DATE = '2019-06-27'; # DATE
+our $VERSION = '0.320'; # VERSION
 
 use 5.010001;
 use strict;
@@ -10,7 +12,6 @@ use warnings;
 # we must not use Log::Any, looping if we are used as log output
 #use Log::Any '$log';
 
-use Carp;
 use File::Spec;
 use IO::Compress::Gzip qw(gzip $GzipError);
 use Scalar::Util qw(weaken);
@@ -26,9 +27,9 @@ sub new {
     my %args;
 
     defined($args{dir} = delete $args0{dir})
-        or croak "Please specify dir";
+        or die "Please specify dir";
     defined($args{prefix} = delete $args0{prefix})
-        or croak "Please specify prefix";
+        or die "Please specify prefix";
     $args{suffix} = delete($args0{suffix}) // "";
 
     $args{size} = delete($args0{size}) // 0;
@@ -36,14 +37,14 @@ sub new {
     $args{period} = delete($args0{period});
     if ($args{period}) {
         $args{period} =~ /\A(daily|day|month|monthly|year|yearly)\z/
-            or croak "Invalid period, please use daily/monthly/yearly";
+            or die "Invalid period, please use daily/monthly/yearly";
     }
 
     for (map {"hook_$_"} qw(before_rotate after_rotate after_create
                             before_write a)) {
         next unless $args0{$_};
         $args{$_} = delete($args0{$_});
-        croak "Invalid $_, please supply a coderef"
+        die "Invalid $_, please supply a coderef"
             unless ref($args{$_}) eq 'CODE';
     }
 
@@ -59,16 +60,16 @@ sub new {
 
     $args{lock_mode} = delete($args0{lock_mode}) // 'write';
     $args{lock_mode} =~ /\A(none|write|exclusive)\z/
-        or croak "Invalid lock_mode, please use none/write/exclusive";
+        or die "Invalid lock_mode, please use none/write/exclusive";
 
     $args{rotate_probability} = delete($args0{rotate_probability});
     if (defined $args{rotate_probability}) {
         $args{rotate_probability} > 0 && $args{rotate_probability} < 1.0
-            or croak "Invalid rotate_probability, must be 0 < x < 1";
+            or die "Invalid rotate_probability, must be 0 < x < 1";
     }
 
     if (keys %args0) {
-        croak "Unknown arguments to new(): ".join(", ", sort keys %args0);
+        die "Unknown arguments to new(): ".join(", ", sort keys %args0);
     }
 
     $args{_buffer} = [];
@@ -170,7 +171,7 @@ sub _get_files {
 
     my @files;
     while (my $e = readdir($dh)) {
-        my $cs = $1 if $e =~ s/(\.gz)\z//; # compress suffix
+        my $cs; $cs = $1 if $e =~ s/(\.gz)\z//; # compress suffix
         next unless $e =~ /\A\Q$self->{prefix}\E
                            (?:\. (?<period>\d{4}(?:-\d\d(?:-\d\d)?)?) )?
                            \Q$self->{suffix}\E
@@ -268,8 +269,13 @@ sub _open {
     my ($fp, $period) = $self->_file_path;
     open $self->{_fh}, ">>", $fp or die "Can't open '$fp': $!";
     if (defined $self->{binmode}) {
-        binmode $self->{_fh}, $self->{binmode}
-          or die "Can't set PerlIO layer on '$fp': $!";
+        if ($self->{binmode} eq "1") {
+            binmode $self->{_fh};
+        } else {
+            binmode $self->{_fh}, $self->{binmode}
+                or die "Can't set PerlIO layer on '$fp' ".
+                    "to '$self->{binmode}': $!";
+        }
     }
     my $oldfh = select $self->{_fh};
     $| = 1;
@@ -397,16 +403,19 @@ sub write {
     }
 }
 
+sub flush {
+}
+
 sub compress {
     my ($self) = shift;
 
-    require Proc::PID::File;
-
     my $lock           = $self->_get_lock;
     my $files_ref        = $self->_get_files;
     my $done_compression = 0;
 
     if (@{$files_ref}) {
+        require Proc::PID::File;
+
         my $pid = Proc::PID::File->new(
             dir    => $self->{dir},
             name   => "$self->{prefix}-compress",
@@ -466,7 +475,7 @@ File::Write::Rotate - Write to files that archive/rotate themselves
 
 =head1 VERSION
 
-This document describes version 0.30 of File::Write::Rotate (from Perl distribution File-Write-Rotate), released on 2016-06-06.
+This document describes version 0.320 of File::Write::Rotate (from Perl distribution File-Write-Rotate), released on 2019-06-27.
 
 =head1 SYNOPSIS
 
@@ -579,6 +588,17 @@ Since this is called indirectly by write(), locking is also already done.
 
 =head2 binmode => str
 
+If set to "1", will cause the file handle to be set:
+
+ binmode $fh;
+
+which might be necessary on some OS, e.g. Windows when writing binary data.
+Otherwise, other defined values will cause the file handle to be set:
+
+ binmode $fh, $value
+
+which can be used to set PerlIO layer(s).
+
 =head1 METHODS
 
 =head2 $obj = File::Write::Rotate->new(%args)
@@ -706,6 +726,10 @@ histories and delete the older ones.
 
 Does not append newline so you'll have to do it yourself.
 
+=head2 $fwr->flush
+
+A no-op, just so the object behaves more like a filehandle object.
+
 =head2 $fwr->compress
 
 Compress old rotated files and remove the uncompressed originals. Currently uses
@@ -757,7 +781,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/File-Write
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-File-Write-Rotate>.
+Source repository is at L<https://github.com/perlancar/perl-File-Write-Rotate>.
 
 =head1 BUGS
 
@@ -811,7 +835,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2019, 2016, 2015, 2014, 2013, 2012 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
